@@ -1,5 +1,9 @@
+
+static const char cright_years_z[] =
+   "1994, 1995, 1996, 2002, 2005";
+
 /* uudecode utility.
-   Copyright (C) 1994, 1995, 1996, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1994, 1995, 1996, 2002, 2005 Free Software Foundation, Inc.
 
    This product is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -374,7 +378,7 @@ decode (inname, forced_outname)
   /* Create output file and set mode.  */
 
   if (strcmp (outname, "/dev/stdout") != 0 && strcmp (outname, "-") != 0
-      && (freopen (outname, "w", stdout) == NULL
+      && (freopen (outname, FOPEN_WRITE_BINARY, stdout) == NULL
 #if HAVE_FCHMOD
 	  || fchmod (fileno (stdout), mode & (S_IRWXU | S_IRWXG | S_IRWXO))
 #else
@@ -462,7 +466,7 @@ main (argc, argv)
 This is free software; see the source for copying conditions.  There is NO\n\
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
 "),
-		  "1994, 1995, 1996, 2002");
+		  cright_years_z);
 	  exit (EXIT_SUCCESS);
 
 	case 0:
